@@ -203,6 +203,8 @@ class Jinja2i18nPlugin(Jinja2Plugin):
             self.app._ = trans.ugettext
             self.prepared[prepared_key] = trans
         except Exception, e:
+            Log.get_instance().error("No locale folder found for translations or problems with importing it.")
+            trans = None
             self.app._ = lambda s: s
             self.prepared[prepared_key] = None
 
